Crate planck_game_features

Crate planck_game_features 

Structs

GameFeaturesSystemBundle
Creates a bundle of systems for the game_features crate.
SkillTriggerEvent
An event where a skill is activated by a specific entity.

Functions

apply_effector_system
Modifies the stats of entities depending on the effectors applied through them (using the EffectorSet component.)
exec_skill_system
Uses the SkillTriggerEvents to apply effectors to the correct entities.
remove_outdated_effector_system
Removes effectors where their time to live is expired. Note: Run after ApplyEffectorsSystem.
skill_cooldown_system
Ticks down the cooldown of skill instances for each entity having a SkillSet component.
trigger_passive_skill_system
Activates passive skills for each entities where all conditions are met using their SkillSet component. Creates SkillTriggerEvent events.