Structs
- Game
Features System Bundle - Creates a bundle of systems for the game_features crate.
- Skill
Trigger Event - An event where a skill is activated by a specific entity.
Functions
- apply_
effector_ system - Modifies the stats of entities depending on the effectors applied through them
(using the
EffectorSetcomponent.) - exec_
skill_ system - Uses the
SkillTriggerEvents to apply effectors to the correct entities. - remove_
outdated_ effector_ system - Removes effectors where their time to live is expired. Note: Run after ApplyEffectorsSystem.
- skill_
cooldown_ system - Ticks down the cooldown of skill instances for each entity having a
SkillSetcomponent. - trigger_
passive_ skill_ system - Activates passive skills for each entities where all conditions are met using
their
SkillSetcomponent. CreatesSkillTriggerEventevents.